run_passthrough

Function run_passthrough 

pub fn run_passthrough(
    program: &str,
    args: &[&str],
    output: &mut dyn Output,
    mode: OutputMode,
) -> Result<CommandResult, ShellError>
Run a command with stdout and stderr inherited from the parent process.

Use this for read-only inspection commands (e.g. outdated) where the output should be displayed directly to the user without any spinner or prefix decoration.